"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Outliner = void 0;
const tagger_1 = require("../tagger");
const common_1 = require("../highlighter/common");
const SourceCodeHighlighter_1 = require("../highlighter/SourceCodeHighlighter");
const mapOptions = new common_1.HighlightConfiguration(10);
class Outliner {
    static create(fileTags, code, contentPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const relPath = fileTags[0].relPath;
            const linesOfInterest = fileTags.map(tag => tag.start.ln);
            const source = { relPath: relPath, code: code };
            return yield Outliner.createFromLOI(linesOfInterest, source, contentPath);
        });
    }
    static createFromLOI(linesOfInterest, source, contentPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const ast = yield (0, tagger_1.createAST)(source, contentPath);
            if (!ast)
                return;
            return new Outliner(source, linesOfInterest, ast);
        });
    }
    constructor(source, linesOfInterest, ast) {
        this.source = source;
        this.linesOfInterest = linesOfInterest;
        this.ast = ast;
    }
    toHighlights() {
        const codeLines = this.source.code.split('\n');
        const highlighter = new SourceCodeHighlighter_1.SourceCodeHighlighter(codeLines, Array.from(this.linesOfInterest).sort(), Array.from(new Set(this.linesOfInterest)).sort());
        if (!highlighter)
            return;
        const highlights = highlighter.toFormattedString();
        return `\n${this.source.relPath}\n${highlights}`;
    }
}
exports.Outliner = Outliner;
//# sourceMappingURL=Outliner.js.map