"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateFileOutline = exports.generateFileOutlineFromTags = exports.createOutlines = void 0;
const Outliner_1 = require("./Outliner");
const tagger_1 = require("../tagger");
const CodeTagExtractor_1 = require("../tagger/CodeTagExtractor");
function createOutlines(sourceSet) {
    return __awaiter(this, void 0, void 0, function* () {
        const extractor = new CodeTagExtractor_1.CodeTagExtractor('', sourceSet.contentPath);
        const defs = yield Promise.all(sourceSet.sources.map((source) => __awaiter(this, void 0, void 0, function* () {
            return yield tagger_1.DefRef.create(extractor, source);
        })));
        return defs.map(defRef => defRef.defs);
    });
}
exports.createOutlines = createOutlines;
function generateFileOutlineFromTags(fileTags, code, contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const highlighter = yield Outliner_1.Outliner.create(fileTags, code, contentPath);
        if (!highlighter)
            return;
        return highlighter.toHighlights();
    });
}
exports.generateFileOutlineFromTags = generateFileOutlineFromTags;
function generateFileOutline(source, linesOfInterest, contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const highlighter = yield Outliner_1.Outliner.createFromLOI(linesOfInterest, source, contentPath);
        if (!highlighter)
            return;
        return highlighter.toHighlights();
    });
}
exports.generateFileOutline = generateFileOutline;
//# sourceMappingURL=index.js.map